# -*- coding: utf-8 -*-
# @Time : 2021/11/8 17:29
# @Author : nobody
# @File : setup.py
# @Software: PyCharm

from setuptools import setup

setup(
    name="pydrops",
    version="1.0.4",
    packages=["hello"]
)